' ***************************************************************************
' * To use a function in a DLL, VB needs to know how the function is        *
' * declared and in which DLL it can be found                               * 
' *                                                                         *
' * A function declaration look like:                                       *
' *                                                                         *
' * Public Declare Function InitInstrument Lib  "hs3.dll"                   *
' *      ( ByVal wAddress As Integer ) As Integer                           *
' *                                                                         *
' *                                                                         *
' * The above declared function is located in a DLL named hs3.dll           * 
' *                                                                         *
' * To use this file with other DLL's, replace all occurances of "hs3.dll"  *
' * by the proper DLL name:                                                 *
' *                                                                         *
' *   - Handyprobe HP2         "hp2.dll"                                    *
' *   - Handyscope HS2         "hs2.dll"                                    *
' *   - Handyscope HS3         "hs3.dll"                                    *
' *   - Handyscope HS4 (DIFF)  "hs4.dll"                                    *
' *   - TiePieSCOPE HS508      "hs508.dll"                                  *
' *   - TiePieSCOPE HS801      "hs801.dll"                                  *
' *   - TP112                  "tp112.dll"                                  *
' *   - TP208                  "tp208.dll"                                  *
' *   - TP508                  "tp508.dll"                                  *
' *   - TP801 ISA              "tp801.dll"                                  *
' *   - TP801 PCI              "pci801.dll"                                 *
' *   - Multi Channel DLL      "MultiCh.dll"                                *
' *                                                                         *
' *                                                                         *
' ***************************************************************************
'
Attribute VB_Name = "Module1"

'  Return codes = bit values. Non-zero is an error:
Public Const E_NO_ERRORS            = &H0000
Public Const E_NO_HARDWARE          = &H0001
Public Const E_NOT_INITIALIZED      = &H0002
Public Const E_NOT_SUPPORTED        = &H0004
Public Const E_NO_GENERATOR         = &H0008
Public Const E_INVALID_CHANNEL      = &H0010
Public Const E_INVALID_VALUE        = &H0020
Public Const E_I2C_ERROR            = &H0040
Public Const E_I2C_INVALID_ADDRESS  = &H0080
Public Const E_I2C_INVALID_SIZE     = &H0100
Public Const E_I2C_NO_ACKNOWLEDGE   = &H0200

'  Channel constants:
Public Const lCh1                   =  1
Public Const lCh2                   =  2
Public Const lCh3                   =  3
Public Const lCh4                   =  4

'  Measure Mode constants, do NOT use for anything else than G/SetMeasureMode().
'  When measuring more channels, simply add the required constants together : e.g. mmCh1 + mmCh2 to measure both Ch1 and Ch2
Public Const mmCh1                  =  1
Public Const mmCh2                  =  2
Public Const mmCh3                  =  4
Public Const mmCh4                  =  8
Public Const mmCh12                 =  3

'  Coupling constants:
Public Const lctAC                  =  0
Public Const lctDC                  =  1

'  Trigger mode constants:
Public Const ltkRising              =  0 '  Trigger when signal passes level in positive direction
Public Const ltkFalling             =  1 '  Trigger when signal passes level in negative direction
Public Const ltkInWindow            =  2 '  Trigger when signal enters marked window
Public Const ltkOutWindow           =  3 '  Trigger when signal leaves marked window
Public Const ltkTVLine              =  4 '  Trigger at TV line sync pulse
Public Const ltkTVFieldOdd          =  5 '  Trigger at Odd TV field sync pulse
Public Const ltkTVFieldEven         =  6 '  Trigger at Even TV field sync pulse
Public Const ltkNet                 =  7 '  Trigger on peaks/dips in the line net
Public Const ltkNthPulse            =  8 '  Trigger on the nth pulse after start of measuring
Public Const ltkPulseLargerM        =  9 '  Trigger if a pulse is larger than M
Public Const ltkPulseSmallerM       = 10 '  Trigger if a pulse is smaller than M
Public Const ltkGlitch              = 11 '  Trigger when the change between two samples is larger than x

'  Trigger source constants:
Public Const ltsCh1                 =  0 '  Trigger on Ch1
Public Const ltsCh2                 =  1 '  Trigger on Ch2
Public Const ltsCh3                 =  2 '  Trigger on Ch3
Public Const ltsCh4                 =  3 '  Trigger on Ch4
Public Const ltsExternal            =  4 '  Trigger on digital external trigger input
Public Const ltsAnalogExt           =  5 '  Trigger on analog external trigger input
Public Const ltsAnd                 =  6 '  Trigger on Ch1 AND Ch2
Public Const ltsOr                  =  7 '  Trigger on Ch1 OR  Ch2
Public Const ltsXor                 =  8 '  Trigger on Ch1 XOR Ch2
Public Const ltsNoTrig              =  9 '  Do not wait for trigger, measure immediately
Public Const ltsNeverTrig           = 10 '  not used
Public Const ltsPxiExt              = 11 '  Trigger on external PXI trigger inputs
Public Const ltsGenStart            = 12 '  Trigger on Generator Start Signal
Public Const ltsGenStop             = 13 '  Trigger on Generator Stop Signal
Public Const ltsGenNew              = 14 '  Trigger on Generator New Period
Public Const ltsUnknown             = 15 '  not used

'  Transfer mode constants:
Public Const ltmBlock               =  0
Public Const ltmStream              =  1

'  Instrument Configuration constants:
Public Const licHS3Norm             =  0
Public Const licHS3256K             =  1
Public Const licHS3512K             =  2

'  FuncGen Modes:
Public Const lfmDDS                 =  1
Public Const lfmLinear              =  2

'  Signal types
Public Const lstSine                =  0
Public Const lstTriangle            =  1
Public Const lstSquare              =  2
Public Const lstDC                  =  3
Public Const lstNoise               =  4
Public Const lstArbitrary           =  5


'  Open / Close the instrument:
Public Declare Function InitInstrument  Lib "hs3.dll" ( ByVal wAddress As Integer ) As Integer
Public Declare Function ExitInstrument  Lib "hs3.dll" (  ) As Integer
 
'  Get information about the instrument:
Public Declare Function GetCalibrationDate  Lib "hs3.dll" ( ByRef dwDate As Long ) As Integer
Public Declare Function GetSerialNumber  Lib "hs3.dll" ( ByRef dwSerialNumber As Long ) As Integer
Public Declare Function GetAvailableSensitivities  Lib "hs3.dll" ( ByRef dSensitivities As Double ) As Integer
Public Declare Function GetAvailableResolutions  Lib "hs3.dll" ( ByRef dResolutions As Double ) As Integer
Public Declare Function GetNrChannels  Lib "hs3.dll" ( ByRef wValue As Integer ) As Integer
Public Declare Function GetMaxSampleFrequencyF  Lib "hs3.dll" (  ) As Double
Public Declare Function GetMaxRecordLength  Lib "hs3.dll" (  ) As Long
Public Declare Function GetDCLevelStatus  Lib "hs3.dll" (  ) As Long
 
'  Measurement routines:
Public Declare Function ADC_Start  Lib "hs3.dll" (  ) As Integer
Public Declare Function ADC_Running  Lib "hs3.dll" (  ) As Integer
Public Declare Function ADC_Abort  Lib "hs3.dll" (  ) As Integer
Public Declare Function ADC_ForceTrig  Lib "hs3.dll" (  ) As Integer
Public Declare Function ADC_Triggered  Lib "hs3.dll" (  ) As Integer
Public Declare Function ADC_Ready  Lib "hs3.dll" (  ) As Integer
 
'  Retrieve the measured data:
Public Declare Function ADC_GetDataCh  Lib "hs3.dll" ( ByVal wCh As Integer , ByRef wChData As Integer ) As Integer
Public Declare Function ADC_GetDataVoltCh  Lib "hs3.dll" ( ByVal wCh As Integer , ByRef dChData As Double ) As Integer
Public Declare Function GetDigitalInputValues  Lib "hs3.dll" ( ByRef wValues As Integer ) As Integer
Public Declare Function GetOneDigitalValue  Lib "hs3.dll" ( ByVal dwIndex As Long , ByRef wValue As Integer ) As Integer
 
'  Streaming measurements:
Public Declare Function SetDataReadyCallback  Lib "hs3.dll" ( ByVal pAddress As Long ) As Integer
Public Declare Function SetDataReadyEvent  Lib "hs3.dll" ( ByVal hEvent As THandle ) As Integer
Public Declare Function SetTransferMode  Lib "hs3.dll" ( ByVal dwMode As Long ) As Integer
Public Declare Function GetTransferMode  Lib "hs3.dll" ( ByRef dwMode As Long ) As Integer
 
'  Control the input resolution in bits:
Public Declare Function SetResolution  Lib "hs3.dll" ( ByVal byValue As Byte ) As Integer
Public Declare Function GetResolution  Lib "hs3.dll" ( ByRef byValue As Byte ) As Integer
 
'  Control the instrument configuration:
Public Declare Function SetInstrumentConfig  Lib "hs3.dll" ( ByVal wMode As Integer ) As Integer
Public Declare Function GetInstrumentConfig  Lib "hs3.dll" ( ByRef wMode As Integer ) As Integer
 
'  Control which channels are measured:
Public Declare Function GetMeasureMode  Lib "hs3.dll" ( ByRef byMode As Byte ) As Integer
Public Declare Function SetMeasureMode  Lib "hs3.dll" ( ByVal byMode As Byte ) As Integer
 
'  Control the time base:
Public Declare Function GetRecordLength  Lib "hs3.dll" (  ) As Long
Public Declare Function SetRecordLength  Lib "hs3.dll" ( ByVal dwRecordLength As Long ) As Integer
Public Declare Function GetPostSamples  Lib "hs3.dll" (  ) As Long
Public Declare Function SetPostSamples  Lib "hs3.dll" ( ByVal dwPostSampleCount As Long ) As Integer
Public Declare Function GetSampleFrequencyF  Lib "hs3.dll" (  ) As Double
Public Declare Function SetSampleFrequencyF  Lib "hs3.dll" ( ByRef dFreq As Double ) As Integer
Public Declare Function GetExternalClock  Lib "hs3.dll" ( ByRef wMode As Integer ) As Integer
Public Declare Function SetExternalClock  Lib "hs3.dll" ( ByVal wMode As Integer ) As Integer
 
'  Control the analog input channels:
Public Declare Function GetSensitivity  Lib "hs3.dll" ( ByVal byCh As Byte , ByRef dSensitivity As Double ) As Integer
Public Declare Function SetSensitivity  Lib "hs3.dll" ( ByVal byCh As Byte , ByRef dSensitivity As Double ) As Integer
Public Declare Function GetAutoRanging  Lib "hs3.dll" ( ByVal byCh As Byte , ByRef byMode As Byte ) As Integer
Public Declare Function SetAutoRanging  Lib "hs3.dll" ( ByVal byCh As Byte , ByVal byMode As Byte ) As Integer
Public Declare Function GetCoupling  Lib "hs3.dll" ( ByVal byCh As Byte , ByRef byMode As Byte ) As Integer
Public Declare Function SetCoupling  Lib "hs3.dll" ( ByVal byCh As Byte , ByVal byMode As Byte ) As Integer
Public Declare Function GetDcLevel  Lib "hs3.dll" ( ByVal byCh As Byte , ByRef dDcLevel As Double ) As Integer
Public Declare Function SetDcLevel  Lib "hs3.dll" ( ByVal byCh As Byte , ByVal dDcLevel As Double ) As Integer
 
'  Control the trigger system:
Public Declare Function GetTriggerSource  Lib "hs3.dll" ( ByRef byTrigSource As Byte ) As Integer
Public Declare Function SetTriggerSource  Lib "hs3.dll" ( ByVal byTrigSource As Byte ) As Integer
Public Declare Function GetTriggerMode  Lib "hs3.dll" ( ByRef byMode As Byte ) As Integer
Public Declare Function SetTriggerMode  Lib "hs3.dll" ( ByVal byMode As Byte ) As Integer
Public Declare Function GetTriggerModeCh  Lib "hs3.dll" ( ByVal byCh As Byte , ByRef byMode As Byte ) As Integer
Public Declare Function SetTriggerModeCh  Lib "hs3.dll" ( ByVal byCh As Byte , ByVal byMode As Byte ) As Integer
Public Declare Function GetTriggerLevel  Lib "hs3.dll" ( ByVal byCh As Byte , ByRef dLevel As Double ) As Integer
Public Declare Function SetTriggerLevel  Lib "hs3.dll" ( ByVal byCh As Byte , ByVal dLevel As Double ) As Integer
Public Declare Function GetTriggerHys  Lib "hs3.dll" ( ByVal byCh As Byte , ByRef dHysteresis As Double ) As Integer
Public Declare Function SetTriggerHys  Lib "hs3.dll" ( ByVal byCh As Byte , ByVal dHysteresis As Double ) As Integer
Public Declare Function GetPXITriggerEnables  Lib "hs3.dll" ( ByRef byEnables As Byte ) As Integer
Public Declare Function SetPXITriggerEnables  Lib "hs3.dll" ( ByVal byEnables As Byte ) As Integer
Public Declare Function GetPXITriggerSlopes  Lib "hs3.dll" ( ByRef bySlopes As Byte ) As Integer
Public Declare Function SetPXITriggerSlopes  Lib "hs3.dll" ( ByVal bySlopes As Byte ) As Integer
 
'  Control the digital outputs:
Public Declare Function SetDigitalOutputs  Lib "hs3.dll" ( ByVal byValue As Byte ) As Integer
Public Declare Function GetDigitalOutputs  Lib "hs3.dll" ( ByRef byValue As Byte ) As Integer
 
'  Square Wave Generator:
Public Declare Function GetSquareWaveGenStatus  Lib "hs3.dll" (  ) As Integer
Public Declare Function GetSquareWaveGenFrequency  Lib "hs3.dll" (  ) As Long
Public Declare Function SetSquareWaveGenFrequency  Lib "hs3.dll" ( ByRef dwFreq As Long ) As Integer
 
'  Get information about the function generator:
Public Declare Function GetFunctionGenStatus  Lib "hs3.dll" (  ) As Integer
Public Declare Function GetFuncGenMaxAmplitude  Lib "hs3.dll" ( ByRef dMaxAmplitude As Double ) As Integer
 
'  Control the Arbitrary Waveform Generator:
Public Declare Function GetFuncGenOutputOn  Lib "hs3.dll" ( ByRef wValue As Integer ) As Integer
Public Declare Function SetFuncGenOutputOn  Lib "hs3.dll" ( ByVal wValue As Integer ) As Integer
Public Declare Function GetFuncGenEnable  Lib "hs3.dll" ( ByRef wValue As Integer ) As Integer
Public Declare Function SetFuncGenEnable  Lib "hs3.dll" ( ByVal wValue As Integer ) As Integer
Public Declare Function GetFuncGenSignalType  Lib "hs3.dll" ( ByRef wValue As Integer ) As Integer
Public Declare Function SetFuncGenSignalType  Lib "hs3.dll" ( ByVal wValue As Integer ) As Integer
Public Declare Function SetFuncGenMode  Lib "hs3.dll" ( ByVal dwMode As Long ) As Integer
Public Declare Function GetFuncGenMode  Lib "hs3.dll" ( ByRef dwMode As Long ) As Integer
Public Declare Function GetFuncGenAmplitude  Lib "hs3.dll" ( ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenAmplitude  Lib "hs3.dll" ( ByVal dValue As Double ) As Integer
Public Declare Function GetFuncGenAmplitudeRange  Lib "hs3.dll" ( ByRef byValue As Byte ) As Integer
Public Declare Function SetFuncGenAmplitudeRange  Lib "hs3.dll" ( ByVal byValue As Byte ) As Integer
Public Declare Function GetFuncGenDCOffset  Lib "hs3.dll" ( ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenDCOffset  Lib "hs3.dll" ( ByVal dValue As Double ) As Integer
Public Declare Function GetFuncGenSymmetry  Lib "hs3.dll" ( ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenSymmetry  Lib "hs3.dll" ( ByVal dValue As Double ) As Integer
Public Declare Function GetFuncGenFrequency  Lib "hs3.dll" ( ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenFrequency  Lib "hs3.dll" ( ByRef dValue As Double ) As Integer
Public Declare Function SetFuncGenTrigSource  Lib "hs3.dll" ( ByVal byTrigSource As Byte ) As Integer
Public Declare Function GetFuncGenTrigSource  Lib "hs3.dll" ( ByRef byTrigSource As Byte ) As Integer
Public Declare Function FillFuncGenMemory  Lib "hs3.dll" ( ByVal dwSampleCount As Long , ByRef FuncGenData As Integer ) As Integer
Public Declare Function FuncGenBurst  Lib "hs3.dll" ( ByVal wNrPeriods As Integer ) As Integer
 
'  Ohm measurements ( not available by default ):
Public Declare Function SetupOhmMeasurements  Lib "hs3.dll" ( ByVal wMode As Integer ) As Integer
Public Declare Function GetOhmValues  Lib "hs3.dll" ( ByRef dValue1 As Double , ByRef dValue2 As Double ) As Integer
 
'  I2C routines:
Public Declare Function I2CWrite  Lib "hs3.dll" ( ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CWriteNoStop  Lib "hs3.dll" ( ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CRead  Lib "hs3.dll" ( ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CReadNoStop  Lib "hs3.dll" ( ByVal dwAddress As Long , ByVal pBuf As pointer , ByVal dwSize As Long ) As Integer
Public Declare Function I2CGetSpeed  Lib "hs3.dll" ( ByRef dwSpeed As Long ) As Integer
Public Declare Function I2CSetSpeed  Lib "hs3.dll" ( ByRef dwSpeed As Long ) As Integer
 
'  Handyscope HS2 Only:
Public Declare Function GetActiveHS2  Lib "hs3.dll" ( ByRef byActiveHS2 As Byte ) As Integer
Public Declare Function SetActiveHS2  Lib "hs3.dll" ( ByVal byActiveHS2 As Byte ) As Integer
Public Declare Function SetDAC1451  Lib "hs3.dll" ( ByVal dMotor1 As Double , ByVal dMotor2 As Double ) As Integer
Public Declare Function SetMotorOn  Lib "hs3.dll" ( ByVal byMotor1 As Byte , ByVal byMotor2 As Byte ) As Integer
 
'  Obsolete routines, use is deprecated:
Public Declare Function GetMaxSampleFrequency  Lib "hs3.dll" (  ) As Long
Public Declare Function StartMeasurement  Lib "hs3.dll" (  ) As Integer
Public Declare Function GetMeasurement  Lib "hs3.dll" ( ByRef dCh1 As Double , ByRef dCh2 As Double ) As Integer
Public Declare Function GetMeasurementRaw  Lib "hs3.dll" ( ByRef wCh1 As Integer , ByRef wCh2 As Integer ) As Integer
Public Declare Function GetOneMeasurement  Lib "hs3.dll" ( ByVal dwIndex As Long , ByRef dCh1 As Double , ByRef dCh2 As Double ) As Integer
Public Declare Function GetOneMeasurementRaw  Lib "hs3.dll" ( ByVal dwIndex As Long , ByRef wCh1 As Integer , ByRef wCh2 As Integer ) As Integer
Public Declare Function GetOneMeasurementRawCh  Lib "hs3.dll" ( ByVal wCh As Integer , ByVal dwIndex As Long , ByRef wChData As Integer ) As Integer
Public Declare Function ADC_GetData  Lib "hs3.dll" ( ByRef wCh1 As Integer , ByRef wCh2 As Integer ) As Integer
Public Declare Function ADC_GetDataVolt  Lib "hs3.dll" ( ByRef dCh1 As Double , ByRef dCh2 As Double ) As Integer
Public Declare Function GetSampleFrequency  Lib "hs3.dll" (  ) As Long
Public Declare Function SetSampleFrequency  Lib "hs3.dll" ( ByRef dwFreq As Long ) As Integer
Public Declare Function GetTriggerTimeOut  Lib "hs3.dll" (  ) As Long
Public Declare Function SetTriggerTimeOut  Lib "hs3.dll" ( ByVal dwTimeout As Long ) As Integer

